@@ -3,7 +3,7 @@
 /***********************************************************************
 *  This code is part of GLPK (GNU Linear Programming Kit).
 *
-*  Copyright (C) 2015-2016 Andrew Makhorin, Department for Applied
+*  Copyright (C) 2015-2018 Andrew Makhorin, Department for Applied
 *  Informatics, Moscow Aviation Institute, Moscow, Russia. All rights
 *  reserved. E-mail: <mao@gnu.org>.
 *
@@ -275,7 +275,7 @@ done: return q;
 *  array bp only the break-points that correspond to positive increment
 *  of the dual objective. */
 
-static int fcmp(const void *v1, const void *v2)
+static int CDECL fcmp(const void *v1, const void *v2)
 {     const SPYBP *p1 = v1, *p2 = v2;
       if (p1->teta < p2->teta)
          return -1;
@@ -497,7 +497,7 @@ int spy_ls_eval_bp(SPXLP *lp, const double d[/*1+n-m*/],
 *  On exit the routine also replaces the parameter slope with a new
 *  value that corresponds to the new last break-point bp[num1]. */
 
-static int fcmp(const void *v1, const void *v2)
+static int CDECL fcmp(const void *v1, const void *v2)
 {     const SPYBP *p1 = v1, *p2 = v2;
       if (p1->teta < p2->teta)
          return -1;
